/*
ID: espr1t
TASK: Incinerator
KEYWORDS: Medium, Binary Search, Geometry
*/

#include <cstdio>
#include <cmath>
#include <cstdlib>
#include <vector>

using namespace std;
FILE* in = stdin; FILE* out = stdout;

const int MAX = 101;
const double EPS = 0.000000000001;

struct Point {
    double x, y;
    Point(double x_ = 0.0, double y_ = 0.0) : x(x_), y(y_) {}
};

struct Circle {
    Point center;
    double radius;
};

int n;
Circle a[MAX];
vector <Point> candidates;
Point answer;

double findDist(Point p1, Point p2) {
    return sqrt((p2.x - p1.x) * (p2.x - p1.x) + (p2.y - p1.y) * (p2.y - p1.y));
}

Point pointOnLine(const Point& p1, const Point& p2, double ratio) {
    return Point(p1.x + (p2.x - p1.x) * ratio, p1.y + (p2.y - p1.y) * ratio); 
}

Point findClosest(const Point& p1, const Point& p2, const Point& target, double offset) {
    double left = 0.0, right = 1.0;
    for (int iter = 0; iter < 100; iter++) {
        double m1 = left + (right - left) / 3.0;
        double m2 = right - (right - left) / 3.0;
        double d1 = fabs(findDist(target, pointOnLine(p1, p2, m1)) - offset);
        double d2 = fabs(findDist(target, pointOnLine(p1, p2, m2)) - offset);
        d1 < d2 ? right = m2 : left = m1;
    }
    return pointOnLine(p1, p2, right);
}

void circleLine(const Circle& circle, const Point& p1, const Point& p2) {
    Point closest = findClosest(p1, p2, circle.center, 0.0);
    if (findDist(closest, circle.center) > circle.radius + EPS)
        return;
    Point cand1 = findClosest(closest, p1, circle.center, circle.radius);
    if (fabs(findDist(cand1, circle.center) - circle.radius) < EPS)
        candidates.push_back(cand1);
    Point cand2 = findClosest(closest, p2, circle.center, circle.radius);
    if (fabs(findDist(cand2, circle.center) - circle.radius) < EPS)
        candidates.push_back(cand2);
}

Point rotate(const Point& origin, const Point& point, double angle) {
    double s = sin(angle), c = cos(angle);
    Point trans(point.x - origin.x, point.y - origin.y);
    return Point(origin.x + trans.x * c - trans.y * s, origin.y + trans.x * s + trans.y * c);
}

void circleCircle(Circle circle1, Circle circle2) {
    double dist = findDist(circle1.center, circle2.center);
    if (dist > circle1.radius + circle2.radius)
        return;
    if (fabs(dist - (circle1.radius + circle2.radius)) < EPS) {
        candidates.push_back(
            pointOnLine(circle1.center, circle2.center,
                        circle1.radius / (circle1.radius + circle2.radius))
        );
        return;
    }
    
    Point p = pointOnLine(circle1.center, circle2.center, circle1.radius / dist);
    double angle = acos(
        (pow(circle1.radius, 2.0) + pow(dist, 2.0) - pow(circle2.radius, 2.0)) / (2.0 * circle1.radius * dist)
    );
    candidates.push_back(rotate(circle1.center, p, +angle));
    candidates.push_back(rotate(circle1.center, p, -angle));
}

bool eval(double radius) {
    for (int i = 0; i < n; i++)
        a[i].radius += radius;
    
    candidates.clear();
    candidates.push_back(Point(0, 0));
    candidates.push_back(Point(0, 1000));
    candidates.push_back(Point(1000, 0));
    candidates.push_back(Point(1000, 1000));
    
    for (int i = 0; i < n; i++) {
        circleLine(a[i], Point(0, 0), Point(0, 1000));
        circleLine(a[i], Point(0, 0), Point(1000, 0));
        circleLine(a[i], Point(1000, 1000), Point(0, 1000));
        circleLine(a[i], Point(1000, 1000), Point(1000, 0));
    }
    
    for (int c1 = 0; c1 < n; c1++) {
        for (int c2 = c1 + 1; c2 < n; c2++) {
            circleCircle(a[c1], a[c2]);
        }
    }
    
//    fprintf(stderr, "  >> number of points to check: %d\n", (int)candidates.size());
    
    answer = Point(-1.0, -1.0);
    for (int i = 0; i < (int)candidates.size(); i++) {
        if (candidates[i].x < 0.0 || candidates[i].x > 1000.0) continue;
        if (candidates[i].y < 0.0 || candidates[i].y > 1000.0) continue;

        bool okay = true;
        for (int c = 0; c < n; c++) {
            if (findDist(candidates[i], a[c].center) < a[c].radius - EPS) {
                okay = false;
                break;
            }
        }
        if (okay) {
            answer = candidates[i];
            break;
        }
    }
    
    for (int i = 0; i < n; i++)
        a[i].radius -= radius;
    return answer.x >= 0.0 && answer.y >= 0.0;
}

double solve() {
    double left = 0.0, right = 2000.0;
    for (int iter = 0; iter < 64; iter++) {
        double mid = (left + right) / 2.0;
        eval(mid) ? left = mid : right = mid;
    }
    eval(left - EPS);
    return left;
}

int main(void) {
    // in = fopen("Incinerator.in", "rt");
    
    fscanf(in, "%d", &n);
    for (int i = 0; i < n; i++)
        fscanf(in, "%lf %lf %lf", &a[i].center.x, &a[i].center.y, &a[i].radius);
    
    fprintf(out, "%.12lf\n", solve());
    // fprintf(out, "%.9lf %.9lf\n", answer.x, answer.y);
    
    return 0;
}
