#include <iostream>
#include <iomanip>
#include <cmath>

typedef double doubleType;
const int ITERS = 64;

struct Circle
{
    doubleType x, y, r;
};

const int MAX_N = 100;
const doubleType BORDER = 1000;

int n;
Circle cs[MAX_N];
doubleType ans;

void input()
{
    std::cin >> n;
    for (int i = 0; i < n; ++i)
    {
        std::cin >> cs[i].x >> cs[i].y >> cs[i].r;
    }
}

void output()
{
    std::cout << std::fixed;
    std::cout << std::setprecision(10);
    std::cout << ans << "\n";
}

// square of number
doubleType sq(doubleType x)
{
    return x * x;
}

// squared distance between points
doubleType sqDist(doubleType x1, doubleType y1, doubleType x2, doubleType y2)
{
    return sq(x1 - x2) + sq(y1 - y2);
}

// checks if point is in circle
bool isIn(doubleType x, doubleType y, const Circle& c, doubleType r2)
{
    return sqDist(x, y, c.x, c.y) < sq(c.r + r2);
}

// solves quadratic equation
bool solveQuad(doubleType a, doubleType b, doubleType c, doubleType& x1, doubleType& x2)
{
    doubleType d = sq(b)- 4 * a * c;
    if (d < 0) return false;
    d = sqrt(d);
    x1 = (-b + d) / (2 * a);
    x2 = (-b - d) / (2 * a);
    return true;
}

// checks if point is a solution
bool checkPoint(doubleType x, doubleType y, doubleType r2, int ign1, int ign2)
{
    if (x < 0 || x > BORDER || y < 0 || y > BORDER) return false;

    for (int i = 0; i < n; ++i)
    {
        if (i == ign1 || i == ign2) continue;
        if (isIn(x, y, cs[i], r2)) return false;
    }

    return true;
}

// intersects borders with circle and checks points
bool interBC(int i, doubleType r2)
{
    const Circle& c = cs[i];

    doubleType rSq = sq(c.r + r2);

    bool bx1, bx2;
    doubleType x11 = 0, x12 = 0, x21 = 0, x22 = 0;

    bx1 = solveQuad(1, -2 * c.x, sq(c.x) + sq(c.y) - rSq, x11, x12);
    bx2 = solveQuad(1, -2 * c.x, sq(c.x) + sq(BORDER) - 2 * BORDER * c.y + sq(c.y) - rSq, x21, x22);

    bool by1, by2;
    doubleType y11 = 0, y12 = 0, y21 = 0, y22 = 0;

    by1 = solveQuad(1, -2 * c.y, sq(c.y) + sq(c.x) - rSq, y11, y12);
    by2 = solveQuad(1, -2 * c.y, sq(c.y) + sq(BORDER) - 2 * BORDER * c.x + sq(c.x) - rSq, y21, y22);

    if (bx1 && checkPoint(x11, 0, r2, i, i)) return true;
    if (bx1 && checkPoint(x12, 0, r2, i, i)) return true;
    if (bx2 && checkPoint(x21, BORDER, r2, i, i)) return true;
    if (bx2 && checkPoint(x22, BORDER, r2, i, i)) return true;
    if (by1 && checkPoint(0, y11, r2, i, i)) return true;
    if (by1 && checkPoint(0, y12, r2, i, i)) return true;
    if (by2 && checkPoint(BORDER, y21, r2, i, i)) return true;
    if (by2 && checkPoint(BORDER, y22, r2, i, i)) return true;

    return false;
}

// intersects circle with circle and checks points
bool interCC(int i, int j, doubleType r2)
{
    const Circle& c1 = cs[i];
    const Circle& c2 = cs[j];

    doubleType dSq = sqDist(c1.x, c1.y, c2.x, c2.y);
    doubleType rSq = sq(c1.r + c2.r + 2 * r2);

    if (dSq > rSq) return false;

    doubleType d = sqrt(dSq);

    doubleType a = (sq(c1.r + r2) - sq(c2.r + r2) + dSq) / (2 * d);
    doubleType h = sqrt(sq(c1.r + r2) - sq(a));

    doubleType x3 = c1.x + a * (c2.x - c1.x) / d;
    doubleType y3 = c1.y + a * (c2.y - c1.y) / d;

    doubleType x41 = x3 + h * (c2.y - c1.y) / d;
    doubleType x42 = x3 - h * (c2.y - c1.y) / d;
    doubleType y41 = y3 - h * (c2.x - c1.x) / d;
    doubleType y42 = y3 + h * (c2.x - c1.x) / d;

    if (checkPoint(x41, y41, r2, i, j)) return true;
    if (checkPoint(x42, y42, r2, i, j)) return true;

    return false;
}

bool check(doubleType r2)
{
    //corners
    if (checkPoint(0, 0, r2, n, n)) return true;
    if (checkPoint(0, BORDER, r2, n, n)) return true;
    if (checkPoint(BORDER, 0, r2, n, n)) return true;
    if (checkPoint(BORDER, BORDER, r2, n, n)) return true;

    //circle with border
    for (int i = 0; i < n; ++i)
    {
        if (interBC(i, r2)) return true;
    }

    //circle with circle
    for (int i = 0; i < n; ++i)
    {
        for (int j = i + 1; j < n; ++j)
        {
           if (interCC(i, j, r2)) return true;
        }
    }

    return false;
}

void solve()
{
    doubleType l = 0;
    doubleType r = 2 * BORDER;

    for (int i = 0; i < ITERS; ++i)
    {
        doubleType m = (l + r) / 2;
        if (check(m)) l = m;
        else r = m;
    }

    ans = l;
}

int main()
{
    // freopen("Incinerator.in", "rt", stdin);
    std::ios::sync_with_stdio(false);
    std::cin.tie(nullptr);

    input();
    solve();
    output();

    return 0;
}
